
# Slot: capable of


holds between a physical entity and process or function, where the continuant alone has the ability to carry out the process or function.

URI: [biolink:capable_of](https://w3id.org/biolink/vocab/capable_of)


## Domain and Range

[NamedThing](NamedThing.md) &#8594;  <sub>0..\*</sub> [Occurrent](Occurrent.md)

## Parents

 *  is_a: [actively involved in](actively_involved_in.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | translator_minimal |
| **Exact Mappings:** | | RO:0002215 |
|  | | RTXKG1:capable_of |
| **Narrow Mappings:** | | NCIT:R52 |
|  | | RO:0002500 |

